@@ -42,21 +42,24 @@ from antlr4.error.Errors import UnsupportedOperationException, RecognitionExcept
 from antlr4.tree.ParseTreePatternMatcher import ParseTreePatternMatcher
 from antlr4.tree.Tree import ParseTreeListener, TerminalNode, ErrorNode
 
-Parser = None
-
 class TraceListener(ParseTreeListener):
-    
-    def enterEveryRule(self, parser:Parser, ctx:ParserRuleContext):
-        print("enter   " + parser.ruleNames[ctx.ruleIndex] + ", LT(1)=" + parser._input.LT(1).text)
 
-    def visitTerminal(self, parser:Parser, node:TerminalNode):
-        print("consume " + node.symbol + " rule " + parser.ruleNames[parser._ctx.ruleIndex])
+    def __init__(self, parser):
+        self._parser = parser
 
-    def visitErrorNode(self, parser:Parser, node:ErrorNode):
+    def enterEveryRule(self, ctx):
+        print("enter   " + self._parser.ruleNames[ctx.getRuleIndex()] + ", LT(1)=" + self._parser._input.LT(1).text)
+
+    def visitTerminal(self, node):
+
+        print("consume " + str(node.symbol) + " rule " + self._parser.ruleNames[self._parser._ctx.getRuleIndex()])
+
+    def visitErrorNode(self, node):
         pass
 
-    def exitEveryRule(self, parser:Parser, ctx:ParserRuleContext):
-        print("exit    " + parser.ruleNames[ctx.ruleIndex] + ", LT(1)=" + parser._input.LT(1).text)
+
+    def exitEveryRule(self, ctx):
+        print("exit    " + self._parser.ruleNames[ctx.getRuleIndex()] + ", LT(1)=" + self._parser._input.LT(1).text)
 
 
 # self is all the parsing support code essentially; most of it is error recovery stuff.#
@@ -288,8 +291,8 @@ class Parser (Recognizer):
         if lexer is None:
             if self.getTokenStream() is not None:
                 tokenSource = self.getTokenStream().getTokenSource()
-            if isinstance( tokenSource, Lexer ):
-                lexer = tokenSource
+                if isinstance( tokenSource, Lexer ):
+                    lexer = tokenSource
         if lexer is None:
             raise UnsupportedOperationException("Parser can't discover a lexer to use")
 
@@ -578,5 +581,5 @@ class Parser (Recognizer):
         else:
             if self._tracer is not None:
                 self.removeParseListener(self._tracer)
-            self._tracer = TraceListener()
+            self._tracer = TraceListener(self)
             self.addParseListener(self._tracer)
