@@ -238,20 +238,20 @@ class ArrayPredictionContext(PredictionContext):
         if self.isEmpty():
             return "[]"
         with StringIO() as buf:
-            buf.write(u"[")
+            buf.write("[")
             for i in range(0,len(self.returnStates)):
                 if i>0:
-                    buf.write(u", ")
+                    buf.write(", ")
                 if self.returnStates[i]==PredictionContext.EMPTY_RETURN_STATE:
-                    buf.write(u"$")
+                    buf.write("$")
                     continue
                 buf.write(self.returnStates[i])
                 if self.parents[i] is not None:
                     buf.write(' ')
                     buf.write(str(self.parents[i]))
                 else:
-                    buf.write(u"null")
-            buf.write(u"]")
+                    buf.write("null")
+            buf.write("]")
             return buf.getvalue()
 
 
@@ -303,9 +303,9 @@ def merge(a:PredictionContext, b:PredictionContext, rootIsWildcard:bool, mergeCa
 
     # convert singleton so both are arrays to normalize
     if isinstance( a, SingletonPredictionContext ):
-        a = ArrayPredictionContext(a)
+        a = ArrayPredictionContext([a.parent], [a.returnState])
     if isinstance( b, SingletonPredictionContext):
-        b = ArrayPredictionContext(b)
+        b = ArrayPredictionContext([b.parent], [b.returnState])
     return mergeArrays(a, b, rootIsWildcard, mergeCache)
 
 
