@@ -113,10 +113,10 @@ class LexerNoViableAltException(RecognitionException):
 
     def __str__(self):
         symbol = ""
-        if self.startIndex >= 0 and self.startIndex < self.input.size():
-            symbol = self.input.getText((self.startIndex,self.startIndex))
+        if self.startIndex >= 0 and self.startIndex < self.input.size:
+            symbol = self.input.getText(self.startIndex, self.startIndex)
             # TODO symbol = Utils.escapeWhitespace(symbol, false);
-        return "LexerNoViableAltException" + symbol
+        return "LexerNoViableAltException('" + symbol + "')"
 
 # Indicates that the parser could not decide which of two or more paths
 #  to take based upon the remaining input. It tracks the starting token
